@@ -39,18 +39,6 @@ try:
     if getattr(pydantic, "__version__", "1.").startswith("1."):
         raise ImportError  # noqa: TRY301
 
-    # YORE: EOL 3.9: Remove block.
-    if sys.version_info < (3, 10):
-        try:
-            import eval_type_backport  # noqa: F401
-        except ImportError:
-            _logger.debug(
-                "Pydantic needs the `eval-type-backport` package to be installed "
-                "for modern type syntax to work on Python 3.9. "
-                "Deactivating Pydantic validation for Python handler options.",
-            )
-            raise
-
     from inspect import cleandoc
 
     from pydantic import Field as BaseField
@@ -87,14 +75,7 @@ if TYPE_CHECKING:
     from collections.abc import MutableMapping
 
 
-# YORE: EOL 3.9: Remove block.
-_dataclass_options = {"frozen": True}
-if sys.version_info >= (3, 10):
-    _dataclass_options["kw_only"] = True
-
-
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class GoogleStyleOptions:
     """Google style docstring options."""
 
@@ -205,8 +186,7 @@ class GoogleStyleOptions:
     ] = True
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class NumpyStyleOptions:
     """Numpy style docstring options."""
 
@@ -256,8 +236,7 @@ class NumpyStyleOptions:
     ] = True
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class SphinxStyleOptions:
     """Sphinx style docstring options."""
 
@@ -289,8 +268,7 @@ class SphinxStyleOptions:
     ] = True
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class PerStyleOptions:
     """Per style options."""
 
@@ -333,8 +311,7 @@ class PerStyleOptions:
         return cls(**data)
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class AutoStyleOptions:
     """Auto style docstring options."""
 
@@ -382,8 +359,7 @@ class AutoStyleOptions:
         return cls(**data)
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class SummaryOption:
     """Summary option."""
 
@@ -423,9 +399,17 @@ class SummaryOption:
         ),
     ] = False
 
+    type_aliases: Annotated[
+        bool,
+        _Field(
+            group="members",
+            parent="summary",
+            description="Whether to render summaries of type aliases.",
+        ),
+    ] = False
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+
+@dataclass(frozen=True, kw_only=True)
 class PythonInputOptions:
     """Accepted input options."""
 
@@ -510,14 +494,11 @@ class PythonInputOptions:
 
             **Filtering methods**
 
-            [:octicons-heart-fill-24:{ .pulse } Sponsors only](../insiders/index.md){ .insiders } &mdash;
-            [:octicons-tag-24: Insiders 1.11.0](../insiders/changelog.md#1.11.0)
-
             The `public` method will include only public objects:
             those added to `__all__` or not starting with an underscore (except for special methods/attributes).
             """,
         ),
-    ] = field(default_factory=lambda: _DEFAULT_FILTERS.copy())
+    ] = field(default_factory=_DEFAULT_FILTERS.copy)
 
     find_stubs_package: Annotated[
         bool,
@@ -551,6 +532,14 @@ class PythonInputOptions:
         ),
     ] = 2
 
+    inheritance_diagram_direction: Annotated[
+        Literal["TB", "TD", "BT", "RL", "LR"],
+        _Field(
+            group="docstrings",
+            description="The direction of the Mermaid chart presenting the inheritance diagram of a class.",
+        ),
+    ] = "TD"
+
     inherited_members: Annotated[
         bool | list[str],
         _Field(
@@ -797,6 +786,22 @@ class PythonInputOptions:
         ),
     ] = True
 
+    show_docstring_type_aliases: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            description="Whether to display the 'Type Aliases' section in the object's docstring.",
+        ),
+    ] = True
+
+    show_docstring_type_parameters: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            description="Whether to display the 'Type Parameters' section in the object's docstring.",
+        ),
+    ] = True
+
     show_docstring_warns: Annotated[
         bool,
         _Field(
@@ -888,6 +893,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    show_signature_type_parameters: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Show the type parameters in generic classes, methods, functions and type aliases signatures.",
+        ),
+    ] = False
+
     show_signature: Annotated[
         bool,
         _Field(
@@ -960,6 +973,14 @@ class PythonInputOptions:
         ),
     ] = ""
 
+    type_parameter_headings: Annotated[
+        bool,
+        _Field(
+            group="headings",
+            description="Whether to render headings for type parameters (therefore showing type parameters in the ToC).",
+        ),
+    ] = False
+
     unwrap_annotated: Annotated[
         bool,
         _Field(
@@ -1001,9 +1022,15 @@ class PythonInputOptions:
         if "summary" in data:
             summary = data["summary"]
             if summary is True:
-                summary = SummaryOption(attributes=True, functions=True, classes=True, modules=True)
+                summary = SummaryOption(attributes=True, functions=True, classes=True, modules=True, type_aliases=True)
             elif summary is False:
-                summary = SummaryOption(attributes=False, functions=False, classes=False, modules=False)
+                summary = SummaryOption(
+                    attributes=False,
+                    functions=False,
+                    classes=False,
+                    modules=False,
+                    type_aliases=False,
+                )
             else:
                 summary = SummaryOption(**summary)
             data["summary"] = summary
@@ -1015,8 +1042,7 @@ class PythonInputOptions:
         return cls(**cls.coerce(**data))
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
     """Final options passed as template context."""
 
@@ -1028,16 +1054,12 @@ class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
     """A list of filters, or `"public"`."""
 
     summary: SummaryOption = field(default_factory=SummaryOption)
-    """Whether to render summaries of modules, classes, functions (methods) and attributes."""
+    """Whether to render summaries of modules, classes, functions (methods), attributes and type aliases."""
 
     @classmethod
     def coerce(cls, **data: Any) -> MutableMapping[str, Any]:
         """Create an instance from a dictionary."""
-        if "filters" in data:
-            # Non-insiders: transform back to default filters.
-            # Next: `if "filters" in data and not isinstance(data["filters"], str):`.
-            if data["filters"] == "public":
-                data["filters"] = _DEFAULT_FILTERS
+        if "filters" in data and not isinstance(data["filters"], str):
             # Filters are `None` or a sequence of strings (tests use tuples).
             data["filters"] = [
                 (re.compile(filtr.removeprefix("!")), filtr.startswith("!")) for filtr in data["filters"] or ()
@@ -1045,8 +1067,7 @@ class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
         return super().coerce(**data)
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class Inventory:
     """An inventory."""
 
@@ -1079,8 +1100,7 @@ class Inventory:
         return {"base_url": self.base_url, "domains": self.domains}
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class PythonInputConfig:
     """Python handler configuration."""
 
@@ -1122,8 +1142,7 @@ class PythonInputConfig:
         return cls(**cls.coerce(**data))
 
 
-# YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
-@dataclass(**_dataclass_options)  # type: ignore[call-overload]
+@dataclass(frozen=True, kw_only=True)
 class PythonConfig(PythonInputConfig):  # type: ignore[override,unused-ignore]
     """Python handler configuration."""
 
